==> estateplat-common-1.2.4-20200811.012941-407-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxFyCf.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/5/31
 * @description 法院查封
 */
@Table(name = "gx_fy_cf")
public class GxFyCf implements Serializable {
    //权利id
    @Id
    private String qlid;
    //业务信息id
    private String ywid;
    //登记类型
    private String djlx;
    //不动产单元号
    private String bdcdyh;
    //坐落
    private String zl;
    //不动产类型
    private String bdclx;
    //面积
    private Double mj;
    //用途
    private String yt;
    //录入证号
    private String lrzh;
    //房产证号
    private String fczh;
    //土地证号
    private String tdzh;
    //查封类型
    private String cflx;
    //查封范围
    private String cffw;
    //查封开始日期
    private Date cfksrq;
    //查封结束日期
    private Date cfjsrq;
    //查封文号
    private String cfwh;
    //限制权利编号
    private String xzqlbh;
    //查封机关
    private String cfjg;
    //查封文件
    private String cfwj;
    //解封文号
    private String jfwh;
    //解封机关
    private String jfjg;
    //解封文件
    private String jfwj;
    //解封时间
    private Date jfsj;
    //原查封文号
    private String ycfwh;
    //产权qlid
    private String cqqlid;

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getLrzh() {
        return lrzh;
    }

    public void setLrzh(String lrzh) {
        this.lrzh = lrzh;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public Date getCfksrq() {
        return cfksrq;
    }

    public void setCfksrq(Date cfksrq) {
        this.cfksrq = cfksrq;
    }

    public Date getCfjsrq() {
        return cfjsrq;
    }

    public void setCfjsrq(Date cfjsrq) {
        this.cfjsrq = cfjsrq;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getXzqlbh() {
        return xzqlbh;
    }

    public void setXzqlbh(String xzqlbh) {
        this.xzqlbh = xzqlbh;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public String getYcfwh() {
        return ycfwh;
    }

    public void setYcfwh(String ycfwh) {
        this.ycfwh = ycfwh;
    }

    public String getCqqlid() {
        return cqqlid;
    }

    public void setCqqlid(String cqqlid) {
        this.cqqlid = cqqlid;
    }
}

==> estateplat-common-1.2.4-20200915.063902-438-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxFyCf.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version 1.0, 2019/5/31
 * @description 法院查封
 */
@Table(name = "gx_fy_cf")
public class GxFyCf implements Serializable {
    //权利id
    @Id
    private String qlid;
    //业务信息id
    private String ywid;
    //登记类型
    private String djlx;
    //不动产单元号
    private String bdcdyh;
    //坐落
    private String zl;
    //不动产类型
    private String bdclx;
    //面积
    private Double mj;
    //用途
    private String yt;
    //录入证号
    private String lrzh;
    //房产证号
    private String fczh;
    //土地证号
    private String tdzh;
    //查封类型
    private String cflx;
    //查封范围
    private String cffw;
    //查封开始日期
    private Date cfksrq;
    //查封结束日期
    private Date cfjsrq;
    //查封文号
    private String cfwh;
    //限制权利编号
    private String xzqlbh;
    //查封机关
    private String cfjg;
    //查封文件
    private String cfwj;
    //解封文号
    private String jfwh;
    //解封机关
    private String jfjg;
    //解封文件
    private String jfwj;
    //解封时间
    private Date jfsj;
    //原查封文号
    private String ycfwh;
    //录入证号qlid
    private String lrzhqlid;

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public String getYwid() {
        return ywid;
    }

    public void setYwid(String ywid) {
        this.ywid = ywid;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getLrzh() {
        return lrzh;
    }

    public void setLrzh(String lrzh) {
        this.lrzh = lrzh;
    }

    public String getFczh() {
        return fczh;
    }

    public void setFczh(String fczh) {
        this.fczh = fczh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public String getCflx() {
        return cflx;
    }

    public void setCflx(String cflx) {
        this.cflx = cflx;
    }

    public String getCffw() {
        return cffw;
    }

    public void setCffw(String cffw) {
        this.cffw = cffw;
    }

    public Date getCfksrq() {
        return cfksrq;
    }

    public void setCfksrq(Date cfksrq) {
        this.cfksrq = cfksrq;
    }

    public Date getCfjsrq() {
        return cfjsrq;
    }

    public void setCfjsrq(Date cfjsrq) {
        this.cfjsrq = cfjsrq;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getXzqlbh() {
        return xzqlbh;
    }

    public void setXzqlbh(String xzqlbh) {
        this.xzqlbh = xzqlbh;
    }

    public String getCfjg() {
        return cfjg;
    }

    public void setCfjg(String cfjg) {
        this.cfjg = cfjg;
    }

    public String getCfwj() {
        return cfwj;
    }

    public void setCfwj(String cfwj) {
        this.cfwj = cfwj;
    }

    public String getJfwh() {
        return jfwh;
    }

    public void setJfwh(String jfwh) {
        this.jfwh = jfwh;
    }

    public String getJfjg() {
        return jfjg;
    }

    public void setJfjg(String jfjg) {
        this.jfjg = jfjg;
    }

    public String getJfwj() {
        return jfwj;
    }

    public void setJfwj(String jfwj) {
        this.jfwj = jfwj;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public String getYcfwh() {
        return ycfwh;
    }

    public void setYcfwh(String ycfwh) {
        this.ycfwh = ycfwh;
    }

    public String getLrzhqlid() {
        return lrzhqlid;
    }

    public void setLrzhqlid(String lrzhqlid) {
        this.lrzhqlid = lrzhqlid;
    }
}
